==> haskell-ghc-lib-parser-ex-9.2.1.1-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser-ex
version:              9.2.1.1
visibility:           public
id:                   ghc-lib-parser-ex-9.2.1.1-5L0z7kOzPx223Cvs3EHhZR
key:                  ghc-lib-parser-ex-9.2.1.1-5L0z7kOzPx223Cvs3EHhZR
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  3e02bd7d2b56a0195e897de5fe7a9061
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.2.1.1-5L0z7kOzPx223Cvs3EHhZR
include-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1/include

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 ghc-9.2.8
    ghc-boot-9.2.8 ghc-boot-th-9.2.8
    uniplate-1.6.13-3kspk5MenPh76qCYq10Rz1

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-ex-9.2.1.1-17-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser-ex
version:              9.2.1.1
visibility:           public
id:                   ghc-lib-parser-ex-9.2.1.1-2wJWCYR2oBS7seNPbu7R8W
key:                  ghc-lib-parser-ex-9.2.1.1-2wJWCYR2oBS7seNPbu7R8W
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  cfdc3a77c750a3c5486d82f115d41b18
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.2.1.1-2wJWCYR2oBS7seNPbu7R8W
include-dirs:
    /usr/lib/ghc-9.2.8/site-local/ghc-lib-parser-ex-9.2.1.1/include

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 ghc-9.2.8
    ghc-boot-9.2.8 ghc-boot-th-9.2.8
    uniplate-1.6.13-1TlVKfWXnEq89IfsWzj5q8

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
